@@ -5,15 +5,6 @@
  */
 package com.jidesoft.swing;
 
-import com.jidesoft.plaf.UIDefaultsLookup;
-import com.jidesoft.popup.JidePopup;
-import com.jidesoft.swing.event.SearchableEvent;
-import com.jidesoft.swing.event.SearchableListener;
-import com.jidesoft.utils.DefaultWildcardSupport;
-import com.jidesoft.utils.WildcardSupport;
-
-import javax.swing.*;
-import javax.swing.event.*;
 import java.awt.*;
 import java.awt.event.*;
 import java.beans.PropertyChangeListener;
@@ -25,6 +16,16 @@ import java.util.Set;
 import java.util.regex.Pattern;
 import java.util.regex.PatternSyntaxException;
 
+import javax.swing.*;
+import javax.swing.event.*;
+
+import com.jidesoft.plaf.UIDefaultsLookup;
+import com.jidesoft.popup.JidePopup;
+import com.jidesoft.swing.event.SearchableEvent;
+import com.jidesoft.swing.event.SearchableListener;
+import com.jidesoft.utils.DefaultWildcardSupport;
+import com.jidesoft.utils.WildcardSupport;
+
 /**
  * JList, JTable and JTree are three data-rich components. They can be used to display a huge amount of data so
  * searching function will be very a useful feature in those components. <code>Searchable</code> is such a class that
@@ -329,7 +330,7 @@ public abstract class Searchable {
     /**
      * The popup panel for search label and search text field.
      */
-    private class DefaultSearchPopup extends SearchPopup {
+    public class DefaultSearchPopup extends SearchPopup {
         private JLabel _label;
         private JLabel _noMatch;
 
@@ -1741,6 +1742,10 @@ public abstract class Searchable {
             return _textField != null ? _textField.getText() : "";
         }
 
+        public JTextField getTextField() {
+           return _textField;
+        }
+
         abstract protected void select(int index, KeyEvent e, String searchingText);
     }
 
