@@ -14,13 +14,12 @@ import java.util.Map;
  * This is a fast access ArrayList that sacrifices memory for speed. It will reduce the speed of indexOf method from
  * O(n) to O(1). However it will at least double the memory used by ArrayList. So use it appropriately. <p><strong>Just
  * like ArrayList, this implementation is not synchronized.</strong> If you want a thread safe implementation, you can
- * use {@link com.jidesoft.utils.CachedVector}.
+ * use {@link com.jidesoft.utils.CachedArrayList}.
  */
 public class CachedArrayList<E> extends ArrayList<E> {
     private static final long serialVersionUID = 3835017332487313880L;
     private Map<Object, IntegerWrapper> _indexCache;
     private boolean _lazyCaching = false;
-    private boolean _isDirty = false;
 
     public CachedArrayList() {
     }
@@ -38,9 +37,7 @@ public class CachedArrayList<E> extends ArrayList<E> {
 
     @Override
     public int indexOf(Object elem) {
-        if (_indexCache == null || _isDirty) {
-            cacheAll();
-        }
+        initializeCache();
         IntegerWrapper o = _indexCache.get(elem);
         if (o != null) {
             return o.integer;
@@ -66,15 +63,21 @@ public class CachedArrayList<E> extends ArrayList<E> {
      *
      * @param index    the index. All values above this index will be changed.
      * @param increase a positive number to increase or a negative number to decrease.
-     * @deprecated no longer being invoked since 3.4.0
      */
-    @Deprecated
     protected synchronized void adjustCache(int index, int increase) {
         if (_indexCache != null) {
-            Collection<IntegerWrapper> values = _indexCache.values();
-            for (IntegerWrapper value : values) {
-                if (value.integer >= index) {
-                    value.integer += increase;
+            if (size() - index <= size() >> 2) {
+                Collection<IntegerWrapper> values = _indexCache.values();
+                for (IntegerWrapper value : values) {
+                    if (value.integer >= index) {
+                        value.integer += increase;
+                    }
+                }
+            }
+            else {
+                uncacheAll();
+                if (!isLazyCaching()) {
+                    cacheAll();
                 }
             }
         }
@@ -84,43 +87,15 @@ public class CachedArrayList<E> extends ArrayList<E> {
         return new IdentityHashMap<Object, IntegerWrapper>();
     }
 
-
     /**
      * Caches the index of the element.
      *
      * @param o     the element
      * @param index the index.
      */
-    public void cacheIt(Object o, int index) {
-        if (_indexCache != null) {
-            IntegerWrapper old = _indexCache.put(o, new IntegerWrapper(index));
-            if (old != null && old.integer < index) {
-                _indexCache.put(o, old);
-            }
-
-            markDirtyIfNecessary(index);
-            if (!_isDirty && !isLazyCaching()) {
-                for (int i = size() - 1; i > index; i--) {
-                    IntegerWrapper oldI = _indexCache.put(get(i), new IntegerWrapper(i));
-                    if (oldI != null && oldI.integer < index) {
-                        _indexCache.put(get(i), oldI);
-                    }
-                }
-            }
-        }
-    }
-
-    /**
-     * Marks the entire cache dirty if necessary depends on where the index is.
-     * <p/>
-     * By default, the cache is marked dirty when the index is smaller than half of the size.
-     *
-     * @param index the index that is changing.
-     * @since 3.4.0
-     */
-    protected void markDirtyIfNecessary(int index) {
-        if (index < size() / 2) {
-            _isDirty = true;
+    public synchronized void cacheIt(Object o, int index) {
+        if (_indexCache != null && (_indexCache.get(o) == null || index < _indexCache.get(o).integer)) {
+            _indexCache.put(o, new IntegerWrapper(index));
         }
     }
 
@@ -129,34 +104,32 @@ public class CachedArrayList<E> extends ArrayList<E> {
      *
      * @param o the element
      */
-    public void uncacheIt(Object o) {
+    public synchronized void uncacheIt(Object o) {
         if (_indexCache != null) {
             _indexCache.remove(o);
         }
     }
 
     @Override
-    public boolean add(E o) {
-        // In any cases, can't invoke add(int, E). Otherwise, StackOverflowError might be thrown.
-        boolean added = super.add(o);
-        if (!isLazyCaching() && _indexCache != null && added) {
-            cacheIt(o, size() - 1);
+    public boolean add(E element) {
+        boolean added = super.add(element);
+        if (!isLazyCaching() && added) {
+            initializeCache();
+            cacheIt(element, size() - 1);
         }
         return added;
     }
 
     @Override
     public void add(int index, E element) {
-        // improve performance for most scenarios in HeaderTableModel
-        if (index == size()) {
-            add(element); // need make sure add(E) won't invoke this method. Otherwise, it will cause endless loop.
-            return;
-        }
         super.add(index, element);
         if (!isLazyCaching()) {
+            initializeCache();
+            adjustCache(index, 1);
             cacheIt(element, index);
         }
         else if (_indexCache != null) {
+            adjustCache(index, 1);
             cacheIt(element, index);
         }
     }
@@ -171,16 +144,19 @@ public class CachedArrayList<E> extends ArrayList<E> {
     public E remove(int index) {
         E element = super.remove(index);
         if (element != null) {
-            uncacheAll();
+            uncacheIt(element);
+            adjustCache(index, -1);
         }
         return element;
     }
 
     @Override
     public boolean remove(Object o) {
+        int oldIndex = indexOf(o);
         boolean removed = super.remove(o);
         if (removed) {
-            uncacheAll();
+            uncacheIt(o);
+            adjustCache(oldIndex, -1);
         }
         return removed;
     }
@@ -201,26 +177,20 @@ public class CachedArrayList<E> extends ArrayList<E> {
 
     @Override
     public boolean addAll(Collection<? extends E> c) {
-        // In any cases, can't invoke addAll(int, Collection<? extends E>). Otherwise, StackOverflowError might be thrown.
-        int index = size();
         boolean added = super.addAll(c);
-        if (added && _indexCache != null) {
-            for (E e : c) {
-                cacheIt(e, index++);
-            }
+        if (added) {
+            cacheAll();
         }
         return added;
     }
 
     @Override
     public boolean addAll(int index, Collection<? extends E> c) {
-        // improve performance for most scenarios in HeaderTableModel
-        if (index == size()) {
-            return this.addAll(c); // need make sure addAll(Collection<? extends E>) won't invoke this method. Otherwise, it will cause endless loop.
-        }
         boolean added = super.addAll(index, c);
-        if (added) {
-            uncacheAll();
+        initializeCache();
+        adjustCache(index, c.size());
+        for (E e : c) {
+            cacheIt(e, index++);
         }
         return added;
     }
@@ -228,8 +198,11 @@ public class CachedArrayList<E> extends ArrayList<E> {
     @Override
     public E set(int index, E element) {
         if (!isLazyCaching()) {
-            uncacheAll();
-            return super.set(index, element);
+            initializeCache();
+            E e = super.set(index, element);
+            uncacheIt(e);
+            cacheIt(element, index);
+            return e;
         }
         else {
             return super.set(index, element);
@@ -246,7 +219,7 @@ public class CachedArrayList<E> extends ArrayList<E> {
     /**
      * Uncache the whole cache. It is the same as {@link #invalidateCache()}.
      */
-    public void uncacheAll() {
+    public synchronized void uncacheAll() {
         if (_indexCache != null) {
             _indexCache.clear();
             _indexCache = null;
@@ -256,22 +229,15 @@ public class CachedArrayList<E> extends ArrayList<E> {
     /**
      * Cache all the element index.
      */
-    public void cacheAll() {
+    public synchronized void cacheAll() {
         _indexCache = createCache();
-//        Integer i = 0;
-//        for (Object elem : this) {
-//            if (_indexCache.get(elem) == null) {
-//                _indexCache.put(elem, i);
-//            }
-//            i++;
-//        }
-//        for (int i = 0; i < size(); i++) {
-//            _indexCache.put(get(i), i);
-//        }
-        for (int i = size() - 1; i >= 0; i--) {
-            _indexCache.put(get(i), new IntegerWrapper(i));
+        Integer i = 0;
+        for (Object elem : this) {
+            if (_indexCache.get(elem) == null) {
+                _indexCache.put(elem, new IntegerWrapper(i));
+            }
+            i++;
         }
-        _isDirty = false;
     }
 
     public boolean isLazyCaching() {
@@ -290,6 +256,9 @@ public class CachedArrayList<E> extends ArrayList<E> {
         else {
             super.removeRange(fromIndex, toIndex);
             uncacheAll();
+            if (!isLazyCaching()) {
+                cacheAll();
+            }
         }
     }
 
